import React from "react";
import ReactMapGL from "react-map-gl";
import {
  Marker,
  NavigationControl, 
  FullscreenControl,
  ScaleControl,
  GeolocateControl
} from "react-map-gl";
import "./css/maps.css";

const MAPBOX_TOKEN = "";
const ICON = `M20.2,15.7L20.2,15.7c1.1-1.6,1.8-3.6,1.8-5.7c0-5.6-4.5-10-10-10S2,4.5,2,10c0,2,0.6,3.9,1.6,5.4c0,0.1,0.1,0.2,0.2,0.3
  c0,0,0.1,0.1,0.1,0.2c0.2,0.3,0.4,0.6,0.7,0.9c2.6,3.1,7.4,7.6,7.4,7.6s4.8-4.5,7.4-7.5c0.2-0.3,0.5-0.6,0.7-0.9
  C20.1,15.8,20.2,15.8,20.2,15.7z`;
const LONGITUDE = 14.320570
const LATITUDE = 48.336950
  
export default class Mapbox extends React.Component{
  state = {
    viewport: {
      width: 600,
      height: 400,
      latitude: LATITUDE,
      longitude: LONGITUDE,
      zoom: 15,
      bearing: 0,
      pitch: 0
    }
  };
  
  render() {
    return (
      <ReactMapGL
        {...this.state.viewport}
        onViewportChange={(viewport) => this.setState({viewport})}
        mapboxApiAccessToken={MAPBOX_TOKEN}
        mapStyle="mapbox://styles/mapbox/streets-v11"
      >
        <Marker
          longitude={LONGITUDE}
          latitude={LATITUDE}
          captureClick={false}
          draggable={false}
          offsetTop={-20}
          offsetLeft={-8}
        >
          <svg height={20} viewBox="0 0 24 24" style={{fill: "#343a40", stroke: "none"}}>
            <path d={ICON} />
          </svg>
        </Marker>
        
        <div className="controllers">
          <div>
            <GeolocateControl />
          </div>
          <div>
            <FullscreenControl />
          </div>
          <div>
            <NavigationControl />
          </div>
          <div>
            <ScaleControl />
          </div>
          <small> {'\u00A9'} Mapbox {'\u00A9'} OpenStreetMap </small>
        </div>
      </ReactMapGL>
    );
  }
}